## Repository regarding the THORONDOR package
This repository is the parent folder of the THORONDOR package, it contains the main program, meant to be imported via `pip install THORONDOR`.
There is also an example notebook in the example folder.